from setuptools import setup
setup(
    name="ldaprc",
    version="1.0.1",
    author='Rob McBroom',
    author_email='python-ldaprc@skurfer.com',
    url='https://github.com/skurfer/ldaprc',
    py_modules=['ldaprc'],
    description='Library for reading OpenLDAP settings in Python',
    keywords='configuration settings ldap3 ldap openldap',
)
